@@ -29,7 +29,7 @@ from typing import (
     cast, Any, Callable, ItemsView, Iterable, Iterator, Literal, KeysView, Mapping, 
     Optional, ValuesView, 
 )
-from types import MappingProxyType
+from types import MappingProxyType,  MethodType
 from urllib.parse import quote
 from uuid import uuid4
 from warnings import filterwarnings, warn
@@ -45,6 +45,23 @@ from .util.urlopen import urlopen
 filterwarnings("ignore", category=DeprecationWarning)
 
 
+class method:
+
+    def __init__(self, func):
+        self.__func__ = func
+
+    def __setname__(self, instance, name):
+        self.__method__ = MethodType(self.__func__, instance)
+
+    def __get__(self, instance, type=None):
+        if instance is None:
+            return self
+        return self.__method__
+
+    def __set__(self, instance, value):
+        raise TypeError("can't set value")
+
+
 def _check_response(fn, /):
     def wrapper(*args, **kwds):
         resp = fn(*args, **kwds)
@@ -1366,13 +1383,13 @@ class AlistPath(Mapping, PathLike[str]):
         return self.fs.exists(self.path, self.password, _check=False)
 
     def glob(self, /, pattern: str = "*", ignore_case: bool = False) -> Iterator[AlistPath]:
-        dirname = self.path if self.is_dir else self.parent.path
+        dirname = self.path if self.is_dir() else self.parent.path
         return self.fs.glob(pattern, dirname, self.password, ignore_case=ignore_case, _check=False)
 
     def isdir(self, /) -> bool:
         return self.fs.isdir(self.path, self.password, _check=False)
 
-    @property
+    @method
     def is_dir(self, /):
         try:
             return self["is_dir"]
@@ -1382,7 +1399,6 @@ class AlistPath(Mapping, PathLike[str]):
     def isfile(self, /) -> bool:
         return self.fs.isfile(self.path, self.password, _check=False)
 
-    @property
     def is_file(self, /) -> bool:
         try:
             return not self["is_dir"]
@@ -1487,12 +1503,13 @@ class AlistPath(Mapping, PathLike[str]):
         encoding: Optional[str] = None, 
         errors: Optional[str] = None, 
         newline: Optional[str] = None, 
+        start: int = 0, 
     ):
         if mode not in ("r", "rt", "tr", "rb", "br"):
             raise OSError(errno.EINVAL, f"invalid (or unsupported) mode: {mode!r}")
-        if self.is_dir:
+        if self.is_dir():
             raise IsADirectoryError(errno.EISDIR, self.path)
-        return AlistFileReader(self).wrap(
+        return AlistFileReader(self, start=start).wrap(
             text_mode="b" not in mode, 
             buffering=buffering, 
             encoding=encoding, 
@@ -1605,7 +1622,7 @@ class AlistPath(Mapping, PathLike[str]):
         return type(self)(self.fs, dst_path, dst_password)
 
     def rglob(self, /, pattern: str = "", ignore_case: bool = False) -> Iterator[AlistPath]:
-        dirname = self.path if self.is_dir else self.parent.path
+        dirname = self.path if self.is_dir() else self.parent.path
         return self.fs.rglob(pattern, dirname, self.password, ignore_case=ignore_case, _check=False)
 
     def rmdir(self, /):
@@ -1685,8 +1702,8 @@ class AlistFileReader(HTTPFileReader):
     "Open a file from the alist server."
     path: AlistPath
 
-    def __init__(self, /, path: AlistPath):
-        super().__init__(path.raw_url)
+    def __init__(self, /, path: AlistPath, start: int = 0):
+        super().__init__(path.raw_url, start=start)
         self.__dict__["path"] = path
 
     @cached_property
@@ -2347,14 +2364,14 @@ class AlistFileSystem:
                 if at_end:
                     if subpath.exists():
                         yield subpath
-                elif subpath.is_dir:
+                elif subpath.is_dir():
                     yield from glob_step_match(subpath, j)
             elif typ == "star":
                 if at_end:
                     yield from path.listdir_attr()
                 else:
                     for subpath in path.listdir_attr():
-                        if subpath.is_dir:
+                        if subpath.is_dir():
                             yield from glob_step_match(subpath, j)
             else:
                 for subpath in path.listdir_attr():
@@ -2367,10 +2384,10 @@ class AlistFileSystem:
                     if cref(subpath.name):
                         if at_end:
                             yield subpath
-                        elif subpath.is_dir:
+                        elif subpath.is_dir():
                             yield from glob_step_match(subpath, j)
         path = AlistPath(self, dirname, password)
-        if not path.is_dir:
+        if not path.is_dir():
             return iter(())
         return glob_step_match(path, i)
 
@@ -2632,6 +2649,7 @@ class AlistFileSystem:
         encoding: Optional[str] = None, 
         errors: Optional[str] = None, 
         newline: Optional[str] = None, 
+        start: int = 0, 
         password: str = "", 
         _check: bool = True, 
     ):
@@ -2644,6 +2662,7 @@ class AlistFileSystem:
             encoding=encoding, 
             errors=errors, 
             newline=newline, 
+            start=start, 
         )
 
     def remove(
