@@ -1,4 +1,4 @@
 #!/usr/bin/env python3
 # encoding: utf-8
 
-import _init_mimetypes
+from . import _init_mimetypes # type: ignore
